==> multiselect-two-sides-2.5.5.jar: META-INF/resources/webjars/multiselect-two-sides/2.5.5/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

<a name="2.5.5"></a>
## [2.5.5](https://github.com/crlcu/multiselect/compare/v2.5.2...v2.5.5) (2018-07-25)


### Bug Fixes

* :visible selector is not working on safari, use :not(.hidden) ([beebfe0](https://github.com/crlcu/multiselect/commit/beebfe0))
* [#152](https://github.com/crlcu/multiselect/issues/152) - ignoreDisabled: true does not work with optgroups ([afc5d8c](https://github.com/crlcu/multiselect/commit/afc5d8c))
* [#166](https://github.com/crlcu/multiselect/issues/166) - Searching and Adding elements cause the already selected elements to get added as a hidden element ([ddefce3](https://github.com/crlcu/multiselect/commit/ddefce3))



<a name="2.5.4"></a>
## [2.5.4](https://github.com/crlcu/multiselect/compare/v2.5.3...v2.5.4) (2018-07-17)


### Bug Fixes

* [#166](https://github.com/crlcu/multiselect/issues/166) - Searching and Adding elements cause the already selected elements to get added as a hidden element ([ddefce3](https://github.com/crlcu/multiselect/commit/ddefce3))



<a name="2.5.3"></a>
## [2.5.3](https://github.com/crlcu/multiselect/compare/v2.5.2...v2.5.3) (2018-07-16)


### Bug Fixes

* [#152](https://github.com/crlcu/multiselect/issues/152) - ignoreDisabled: true does not work with optgroups ([afc5d8c](https://github.com/crlcu/multiselect/commit/afc5d8c))



<a name="2.5.2"></a>
## [2.5.2](https://github.com/crlcu/multiselect/compare/v2.5.1...v2.5.2) (2018-07-10)


### Bug Fixes

* [#164](https://github.com/crlcu/multiselect/issues/164) - Invalid regular expression ([541bb68](https://github.com/crlcu/multiselect/commit/541bb68))



<a name="2.5.1"></a>
## [2.5.1](https://github.com/crlcu/multiselect/compare/v2.5.0...v2.5.1) (2018-04-27)


### Patches

* change the value for the main path ([22414f8](https://github.com/crlcu/multiselect/commit/22414f8))

### Features

* add afterInit event ([22e1523](https://github.com/crlcu/multiselect/commit/22e1523))



<a name="2.5.0"></a>
# [2.5.0](https://github.com/crlcu/multiselect/compare/v2.4.1...v2.5.0) (2018-02-06)


### Features

* now we can have different sort functions for left and right ([887ab4a](https://github.com/crlcu/multiselect/commit/887ab4a))

==> multiselect-two-sides-2.5.7.jar: META-INF/resources/webjars/multiselect-two-sides/2.5.7/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [2.5.7](https://github.com/crlcu/multiselect/compare/v2.5.6...v2.5.7) (2020-05-06)

* Remove unused dependency

### [2.5.6](https://github.com/crlcu/multiselect/compare/v2.5.5...v2.5.6) (2020-05-06)

* Upgrade dev dependencies

<a name="2.5.5"></a>
## [2.5.5](https://github.com/crlcu/multiselect/compare/v2.5.4...v2.5.5) (2018-07-25)


### Bug Fixes

* :visible selector is not working on safari, use :not(.hidden) ([beebfe0](https://github.com/crlcu/multiselect/commit/beebfe0))
* [#152](https://github.com/crlcu/multiselect/issues/152) - ignoreDisabled: true does not work with optgroups ([afc5d8c](https://github.com/crlcu/multiselect/commit/afc5d8c))



<a name="2.5.4"></a>
## [2.5.4](https://github.com/crlcu/multiselect/compare/v2.5.3...v2.5.4) (2018-07-17)


### Bug Fixes

* [#166](https://github.com/crlcu/multiselect/issues/166) - Searching and Adding elements cause the already selected elements to get added as a hidden element ([ddefce3](https://github.com/crlcu/multiselect/commit/ddefce3))



<a name="2.5.3"></a>
## [2.5.3](https://github.com/crlcu/multiselect/compare/v2.5.2...v2.5.3) (2018-07-16)


### Bug Fixes

* [#152](https://github.com/crlcu/multiselect/issues/152) - ignoreDisabled: true does not work with optgroups ([afc5d8c](https://github.com/crlcu/multiselect/commit/afc5d8c))



<a name="2.5.2"></a>
## [2.5.2](https://github.com/crlcu/multiselect/compare/v2.5.1...v2.5.2) (2018-07-10)


### Bug Fixes

* [#164](https://github.com/crlcu/multiselect/issues/164) - Invalid regular expression ([541bb68](https://github.com/crlcu/multiselect/commit/541bb68))



<a name="2.5.1"></a>
## [2.5.1](https://github.com/crlcu/multiselect/compare/v2.5.0...v2.5.1) (2018-04-27)


### Patches

* change the value for the main path ([22414f8](https://github.com/crlcu/multiselect/commit/22414f8))

### Features

* add afterInit event ([22e1523](https://github.com/crlcu/multiselect/commit/22e1523))



<a name="2.5.0"></a>
# [2.5.0](https://github.com/crlcu/multiselect/compare/v2.4.1...v2.5.0) (2018-02-06)


### Features

* now we can have different sort functions for left and right ([887ab4a](https://github.com/crlcu/multiselect/commit/887ab4a))
